@@ -3,7 +3,7 @@
    xsane-icons.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2004 Oliver Rauch
+   Copyright (C) 1998-2005 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -565,6 +565,42 @@ const char *blur_xpm[] =
 
 /* --------------------------------------------------- */
 
+const char *undo_xpm[] =
+{
+/* width height num_colors chars_per_pixel */
+"    20    20        4            1",
+/* colors */
+"* c #000000",
+"+ c #404040",
+". c #808080",
+"  none",
+/* pixels */
+"                    ",
+"                    ",
+"  **     ****       ",
+"  **   ***  ***     ",
+"  ** **        **   ",
+"  ****          **  ",
+"  *******       **  ",
+"  *******        ** ",
+"                 ** ",
+"                 ** ",
+"                 ** ",
+"                 ** ",
+"                 ** ",
+"                 ** ",
+"                 ** ",
+"                **  ",
+"                **  ",
+"                **  ",
+"               **   ",
+"               **   ",
+"               **   ",
+"                    "
+};
+
+/* --------------------------------------------------- */
+
 const char *clone_xpm[] =
 {
 /* width height num_colors chars_per_pixel */
@@ -809,6 +845,38 @@ const char *faxreceiver_xpm[] =
 "    20    20        3            1",
 /* colors */
 "* c #000000",
+"- c #404040",
+"  none",
+/* pixels */
+"         ****       ",
+"     ****    ****   ",
+"   **            ** ",
+" *                 *",
+" *     *******     *",
+"  *   *       *   * ",
+"   ***         ***  ",
+"  *  ** ** ** **  * ",
+"  *  ** ** ** **  * ",
+"  *               * ",
+"  *  ** ** ** **  * ",
+"  *  ** ** ** **  * ",
+"  *               * ",
+"  *  ** ** ** **  * ",
+"  *  ** ** ** **  * ",
+"  *               * ",
+"  *  ** ** ** **  * ",
+"  *  ** ** ** **  * ",
+"  *                *",
+"  ***************** ",
+};
+/* --------------------------------------------------- */
+#if 0
+const char *person_xpm[] =
+{
+/* width height num_colors chars_per_pixel */
+"    20    20        3            1",
+/* colors */
+"* c #000000",
 "- c #e0e0e0",
 "  none",
 /* pixels */
@@ -833,6 +901,7 @@ const char *faxreceiver_xpm[] =
 "   *------***       ",
 "    *----*          ",
 };
+#endif
 
 /* --------------------------------------------------- */
 
